@@ -13,6 +13,13 @@ QT_TRANSLATE_NOOP("server", "REMOVE_TEAM: no such team"),
 QT_TRANSLATE_NOOP("server", "Not team owner!"),
 QT_TRANSLATE_NOOP("server", "Illegal room name"),
 QT_TRANSLATE_NOOP("server", "Room with such name already exists"),
+QT_TRANSLATE_NOOP("server", "/maxteams: specify number from 2 to 8"),
+QT_TRANSLATE_NOOP("server", "Available callvote commands: kick <nickname>, map <name>, pause, newseed, hedgehogs"),
+QT_TRANSLATE_NOOP("server", "callvote kick: specify nickname"),
+QT_TRANSLATE_NOOP("server", "callvote kick: no such user"),
+QT_TRANSLATE_NOOP("server", "callvote map: no such map"),
+QT_TRANSLATE_NOOP("server", "callvote pause: no game in progress"),
+QT_TRANSLATE_NOOP("server", "callvote hedgehogs: specify number from 1 to 8"),
 QT_TRANSLATE_NOOP("server", "Warning! Chat flood protection activated"),
 QT_TRANSLATE_NOOP("server", "Excess flood"),
 QT_TRANSLATE_NOOP("server", "Game messages flood detected - 1"),
@@ -20,12 +27,16 @@ QT_TRANSLATE_NOOP("server", "Game messages flood detected - 2"),
 QT_TRANSLATE_NOOP("server", "Warning! Joins flood protection activated"),
 QT_TRANSLATE_NOOP("server", "There's no voting going on"),
 QT_TRANSLATE_NOOP("server", "You already have voted"),
+QT_TRANSLATE_NOOP("server", "Your vote counted"),
 QT_TRANSLATE_NOOP("server", "Voting closed"),
+QT_TRANSLATE_NOOP("server", "Pause toggled"),
 QT_TRANSLATE_NOOP("server", "New voting started"),
 QT_TRANSLATE_NOOP("server", "Voting expired"),
 QT_TRANSLATE_NOOP("server", "kick"),
 QT_TRANSLATE_NOOP("server", "map"),
 QT_TRANSLATE_NOOP("server", "pause"),
+QT_TRANSLATE_NOOP("server", "new seed"),
+QT_TRANSLATE_NOOP("server", "number of hedgehogs in team"),
 QT_TRANSLATE_NOOP("server", "Nickname is already in use"),
 QT_TRANSLATE_NOOP("server", "No checker rights"),
 QT_TRANSLATE_NOOP("server", "Authentication failed"),
