@@ -54,3 +54,7 @@ function onGearDelete(gear)
 		end
 	end
 end
+
+function onNewTurn()
+    SetWeapon(amBaseballBat)
+end
