@@ -1,5 +1,6 @@
 HedgewarsScriptLoad("/Scripts/Locale.lua")
 HedgewarsScriptLoad("/Scripts/Utils.lua")
+HedgewarsScriptLoad("/Scripts/Params.lua")
 
 local hTag = nil
 local hTagHeight = 33000
@@ -25,6 +26,7 @@ local HogsAreInvulnerable = false
 local WaterRise = nil
 local Cake = nil
 local CakeTries = 0
+local addCake = true
 local Stars = {}
 local tauntNoo = false
 local jokeAwardNavy = nil
@@ -36,6 +38,34 @@ local showWaterStats = false -- uses the AI team to draw water height.
 local scaleGraph = false
 local dummyHog = nil
 local dummySkip = 0
+local baseWaterSpeed = 2
+local waterSpeed = 0
+local waterAccel = 0
+local delayHeight = 32000
+local delayTime = 0
+local airMineX = {}
+local airMineY = {}
+local airMine = {}
+local init = true
+
+function onParameters()
+    parseParams()
+
+    if params["speed"] ~= nil then
+        baseWaterSpeed = params["speed"]
+    end
+    if params["accel"] ~= nil then
+        waterAccel = params["accel"]
+        if waterAccel ~= 0 then waterAccel = div(32640000,waterAccel) end
+    end
+    if params["delaytime"] ~= nil then
+        delayTime = params["delaytime"]
+    end
+    if params["delaytime"] ~= nil then
+        delayHeight = 32768-params["delayheight"]
+    end
+    if params["nocake"] ~= nil then addCake = false end
+end
 
 function onGameInit()
     -- Ensure people get same map for same theme
@@ -58,9 +88,7 @@ function onGameInit()
         dummyHog = AddHog(" ", 0, 1, "NoHat")
         HH[dummyHog] = nil
         totalHedgehogs = totalHedgehogs - 1
-        if not showWaterStats then
-            SendStat(siClanHealth, tostring(32640), " ")
-        end
+        teams[GetHogTeamName(dummyHog)] = nil
         SendStat(siClanHealth, tostring(32640), " ")
     end
 end
@@ -70,6 +98,8 @@ function onGearAdd(gear)
         HH[gear] = 1
         totalHedgehogs = totalHedgehogs + 1
         teams[GetHogTeamName(gear)] = 1
+    elseif init and GetGearType(gear) == gtAirMine then
+        airMine[gear] = 1
     end
 end
 
@@ -80,6 +110,8 @@ function onGearDelete(gear)
     elseif gear == Cake then
         Cake = nil
     elseif GetGearType(gear) == gtHedgehog then
+	onGameTick20()
+	onGearDamage(gear, 0)
         HH[gear] = nil
     end
 end
@@ -118,6 +150,23 @@ function onAmmoStoreInit()
 end
 
 function onNewTurn()
+    if init then
+        init = false
+        for a,i in pairs(airMine) do
+            x,y = GetGearPosition(a)
+            airMineX[a] = x
+            airMineY[a] = y
+        end
+    else
+        for a,i in pairs(airMine) do
+            local x,y = GetGearPosition(a)
+            if not x or airMineX[a] ~= x or airMineY[a] ~= y then
+                DeleteGear(a)
+                AddGear(airMineX[a],airMineY[a], gtAirMine, gsttmpFlag, 0, 0, 0)
+            end
+        end
+    end
+        
     ready = false
     startTime = GameTime
     --disable to preserve highest over multiple turns
@@ -194,7 +243,7 @@ end
 
 
 function onGameTick20()
-    local x,y;
+    local x,y
     if math.random(20) == 1 then AddVisualGear(2012,56,vgtSmoke,0,false) end
     if CurrentHedgehog == dummyHog and dummySkip ~= 0 and dummySkip < GameTime then
         ParseCommand("/skip")
@@ -237,7 +286,15 @@ function onGameTick20()
     end
 
     if CurrentHedgehog ~= nil and TurnTimeLeft > 0 and band(GetState(CurrentHedgehog),gstHHDriven) ~= 0 then
-        if MaxHeight < 32000 and MaxHeight > 286 and WaterLine > 286  then SetWaterLine(WaterLine-2) end
+        if MaxHeight < delayHeight and
+           TurnTimeLeft<(999999999-delayTime) and 
+            MaxHeight > 286 and WaterLine > 286 then
+            if waterAccel ~= 0 then
+                SetWaterLine(WaterLine-(baseWaterSpeed+div(getActualHeight(MaxHeight)*100,waterAccel)))
+            else
+                SetWaterLine(WaterLine-baseWaterSpeed)
+            end
+        end
         if y > 0 and y < 30000 and MaxHeight > 286 and math.random(y) < 500 then
             local s = AddVisualGear(0, 0, vgtStraightShot, 0, true)
             local c = div(250000,y)
@@ -371,7 +428,7 @@ function onGameTick20()
                 end
             end
 
-            if CakeTries < 10 and y < 32600 and y > 3000 and Cake == nil and band(GetState(CurrentHedgehog),gstHHDriven) ~= 0 then 
+            if addCake and CakeTries < 10 and y < 32600 and y > 3000 and Cake == nil and band(GetState(CurrentHedgehog),gstHHDriven) ~= 0 then 
                 -- doing this just after the start the first time to take advantage of randomness sources
                 -- Pick a clear y to start with
                 if y > 31000 then cy = 24585 elseif
@@ -538,6 +595,7 @@ function makeSinglePlayerLoserStats()
     else
         SendStat(siCustomAchievement, string.format(text, RecordHeightHogName))
     end
+    SendStat(siPointType, loc("points"))
     SendStat(siPlayerKills, actualHeight, loc(GetHogTeamName(CurrentHedgehog)))
     EndGame()
 end
@@ -572,7 +630,7 @@ function makeFinalMultiPlayerStats()
     SendStat(siGraphTitle, string.format(loc("Team’s best heights per round")))
     
     if winner.score < 1500 then
-        SendStat(siCustomAchievement, string.format(loc("This round’s award for ulitmate disappointment goes to: Everyone!")))
+        SendStat(siCustomAchievement, string.format(loc("This round’s award for ultimate disappointment goes to: Everyone!")))
     else
         if winner.score > 30000 then text = loc("%s (%s) reached for the sky and beyond with a height of %d!")
         elseif winner.score > 24750 then text = loc("%s (%s) was certainly not afraid of heights: Peak height of %d!")
