@@ -107,7 +107,7 @@ function onGameStart()
 end
 
 function onNewTurn()
-	ParseCommand("setweap " .. string.char(amGrenade))
+	SetWeapon(amGrenade)
 end
 
 -- This function is called every game tick.
@@ -141,7 +141,7 @@ function onGameTick20()
 			-- Remove the team to end the game. Only do this once.
 			if team_death == false then
 				team_death = true
-				ParseCommand("teamgone " .. "Grenadiers")
+				DismissTeam(loc("Grenadiers"))
 			end
 		else
 			-- ... or just lower the timer by 1.
