@@ -21,6 +21,7 @@ ___ .-. .-. ___  ___ | |_    .---. ___ .-. | |_
 
 HedgewarsScriptLoad("/Scripts/Locale.lua")
 HedgewarsScriptLoad("/Scripts/Tracker.lua")
+HedgewarsScriptLoad("/Scripts/Params.lua")
 
 --[[
     MUTANT SCRIPT
@@ -399,7 +400,7 @@ end
 
 function setAIHints()
     for i = 0, #hhs do
-        if mutant == nil or hhs[i] == mutant or CurrentHedgehog == mutant then
+        if mutant == nil or hhs[i] == mutant or CurrentHedgehog == mutant or getGearValue(CurrentHedgehog, "Feeder") then
             SetGearAIHints(hhs[i], aihUsual)
         else
             SetGearAIHints(hhs[i], aihDoesntMatter)
@@ -607,6 +608,11 @@ function onGearDelete(gear)
     end
 end
 
+function onParameters()
+    parseParams()
+    winScore = tonumber(params["winscore"]) or winScore
+end
+
 --[[
 S T A R R I N G
     prof - Coding, implementing and evangelism
